==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/filestreamsmanager.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>FileStream</name>
    <message>
        <source>Connecting</source>
        <translation>Verbinde</translation>
    </message>
    <message>
        <source>Disconnecting</source>
        <translation>Verbindungsabbruch</translation>
    </message>
    <message>
        <source>Waiting for a response to send a file request</source>
        <translation>Warte auf Antwort um eine Dateianfrage zu senden</translation>
    </message>
    <message>
        <source>Data transmission</source>
        <translation>Datenübertragung</translation>
    </message>
    <message>
        <source>Data transmission finished</source>
        <translation>Datenübertragung fertig gestellt</translation>
    </message>
    <message>
        <source>Data transmission terminated by remote user</source>
        <translation>Datenübertragen wurde vom Benutzer abgebrochen</translation>
    </message>
    <message>
        <source>Connection timed out</source>
        <translation></translation>
    </message>
    <message>
        <source>File size unexpectedly changed</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FileStreamsManager</name>
    <message>
        <source>File Streams Manager</source>
        <translation>Dateistreams Manager</translation>
    </message>
    <message>
        <source>File Transfers</source>
        <translation>Dateiübertragungen</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>File Transfer</source>
        <translation>Dateiübertragungen</translation>
    </message>
    <message>
        <source>Allows to initiate a thread for transferring files between two XMPP entities</source>
        <translation>Erlaubt das Initiieren eines Thread für die Übertragen von Dateien zwischen zwei XMPP Existenzen</translation>
    </message>
    <message>
        <source>Show file transfers</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FileStreamsOptions</name>
    <message>
        <source>Select default directory</source>
        <translation>Standardverzeichnis auswählen</translation>
    </message>
</context>
<context>
    <name>FileStreamsOptionsClass</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Default Downloads Directory:</source>
        <translation>Standard Downloadverzeichnis:</translation>
    </message>
    <message>
        <source>Default Data Stream:</source>
        <translation>Standard Datenstream:</translation>
    </message>
    <message>
        <source>Acceptable Data Streams</source>
        <translation>Zu akzeptierende Datenstreams</translation>
    </message>
    <message>
        <source>Group downloads by sender</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FileStreamsWindow</name>
    <message>
        <source>File Name</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Erstellen</translation>
    </message>
    <message>
        <source>Negotiate</source>
        <translation>Abschließen</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transfer</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Verbindung beenden</translation>
    </message>
    <message>
        <source>Finished</source>
        <translation>Fertig gestellt</translation>
    </message>
    <message>
        <source>Aborted</source>
        <translation>Abgebrochen</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>/sec</source>
        <translation>/sek</translation>
    </message>
    <message>
        <source>B</source>
        <comment>Byte</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KB</source>
        <comment>Kilobyte</comment>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <comment>Megabyte</comment>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <comment>Gigabyte</comment>
        <translation>GB</translation>
    </message>
    <message>
        <source>Downloads: %1 at %2</source>
        <translation>Downloads: %1 bei %2</translation>
    </message>
    <message>
        <source>Uploads: %1 at %2</source>
        <translation>Uploads: %1 bei %2</translation>
    </message>
    <message>
        <source>Active: %1/%2</source>
        <translation>Aktive: %1/%2</translation>
    </message>
    <message>
        <source>File Transfers</source>
        <translation>Dateiübertragungen</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/filestreamsmanager.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>FileStream</name>
    <message>
        <source>Connecting</source>
        <translation>Verbinde</translation>
    </message>
    <message>
        <source>Disconnecting</source>
        <translation>Trenne</translation>
    </message>
    <message>
        <source>Waiting for a response to send a file request</source>
        <translation>Warte auf Antwort um eine Dateianfrage zu senden</translation>
    </message>
    <message>
        <source>Data transmission</source>
        <translation>Datenübertragung</translation>
    </message>
    <message>
        <source>Data transmission finished</source>
        <translation>Datenübertragung beendet</translation>
    </message>
    <message>
        <source>Data transmission terminated by remote user</source>
        <translation>Datenübertragen wurde vom anderen Benutzer abgebrochen</translation>
    </message>
    <message>
        <source>Connection timed out</source>
        <translation>Zeitüberschreitung bei Verbindung</translation>
    </message>
    <message>
        <source>File size unexpectedly changed</source>
        <translation>Unerwartete Änderung der Dateigröße</translation>
    </message>
</context>
<context>
    <name>FileStreamsManager</name>
    <message>
        <source>File Streams Manager</source>
        <translation>Dateiaustausch Manager</translation>
    </message>
    <message>
        <source>File Transfers</source>
        <translation>Dateiübertragungen</translation>
    </message>
    <message>
        <source>File Transfer</source>
        <translation>Dateiübertragung</translation>
    </message>
    <message>
        <source>Allows to initiate a thread for transferring files between two XMPP entities</source>
        <translation>Erlaubt das Anlegen von seperaten Übertragungen von Dateien zwischen zwei XMPP Endpunkten</translation>
    </message>
    <message>
        <source>Show file transfers</source>
        <translation>Zeige Dateiübertragungen</translation>
    </message>
</context>
<context>
    <name>FileStreamsOptions</name>
    <message>
        <source>Select default directory</source>
        <translation>Standardverzeichnis auswählen</translation>
    </message>
</context>
<context>
    <name>FileStreamsOptionsClass</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Default Downloads Directory:</source>
        <translation>Standard Downloadverzeichnis:</translation>
    </message>
    <message>
        <source>Default Data Stream:</source>
        <translation>Standard Datenstrom:</translation>
    </message>
    <message>
        <source>Acceptable Data Streams</source>
        <translation>Akzeptierbare Datenströme</translation>
    </message>
    <message>
        <source>Group downloads by sender</source>
        <translation>Downloads nach Sender gruppieren</translation>
    </message>
</context>
<context>
    <name>FileStreamsWindow</name>
    <message>
        <source>File Name</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Erstellen</translation>
    </message>
    <message>
        <source>Negotiate</source>
        <translation>Abschließen</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transfer</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Trennen</translation>
    </message>
    <message>
        <source>Finished</source>
        <translation>Beended</translation>
    </message>
    <message>
        <source>Aborted</source>
        <translation>Abgebrochen</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>/sec</source>
        <translation>/sek</translation>
    </message>
    <message>
        <source>B</source>
        <comment>Byte</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KB</source>
        <comment>Kilobyte</comment>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <comment>Megabyte</comment>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <comment>Gigabyte</comment>
        <translation>GB</translation>
    </message>
    <message>
        <source>Downloads: %1 at %2</source>
        <translation>Downloads: %1 bei %2</translation>
    </message>
    <message>
        <source>Uploads: %1 at %2</source>
        <translation>Uploads: %1 bei %2</translation>
    </message>
    <message>
        <source>Active: %1/%2</source>
        <translation>Aktive: %1/%2</translation>
    </message>
    <message>
        <source>File Transfers</source>
        <translation>Dateiübertragungen</translation>
    </message>
</context>
</TS>
